@@ -1,8 +1,6 @@
 package Dancer::Session::Cookie;
-BEGIN {
-  $Dancer::Session::Cookie::AUTHORITY = 'cpan:YANICK';
-}
-$Dancer::Session::Cookie::VERSION = '0.24';
+our $AUTHORITY = 'cpan:YANICK';
+$Dancer::Session::Cookie::VERSION = '0.26';
 use strict;
 use warnings;
 # ABSTRACT: Encrypted cookie-based session backend for Dancer
@@ -197,7 +195,7 @@ Dancer::Session::Cookie - Encrypted cookie-based session backend for Dancer
 
 =head1 VERSION
 
-version 0.24
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -219,6 +217,11 @@ module uses cryptography to ensure integrity and also secrecy. The
 data your application stores in sessions is completely protected from
 both tampering and analysis on the client-side.
 
+Do be aware that browsers limit the size of individual cookies, so this method
+is not suitable if you wish to store a large amount of data.  Browsers typically
+limit the size of a cookie to 4KB, but that includes the space taken to store
+the cookie's name, expiration and other attributes as well as its content.
+
 =head1 CONFIGURATION
 
 The setting B<session> should be set to C<cookie> in order to use this session
@@ -228,10 +231,15 @@ A mandatory setting is needed as well: B<session_cookie_key>, which should
 contain a random string of at least 16 characters (shorter keys are
 not cryptographically strong using AES in CBC mode).
 
+The optional B<session_expires> setting can also be passed, 
+which will provide the duration time of the cookie. If it's not present, the
+cookie won't have an expiration value.
+
 Here is an example configuration to use in your F<config.yml>:
 
     session: "cookie"
     session_cookie_key: "kjsdf07234hjf0sdkflj12*&(@*jk"
+    session_expires: 1 hour
 
 Compromising B<session_cookie_key> will disclose session data to
 clients and proxies or eavesdroppers and will also allow tampering,
@@ -284,7 +292,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Alex Kapranoff.
+This software is copyright (c) 2015 by Alex Kapranoff.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
